@@ -2,7 +2,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2012 by Dominique Dumont.
+# This software is Copyright (c) 2014 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -109,7 +109,6 @@
 
     [
         name              => 'MasterModel',
-        permission        => [ [qw/tree_macro/] => 'advanced' ],
         class_description => "Master description",
         level             => [ [qw/hash_a tree_macro int_v/] => 'important' ],
 
@@ -260,7 +259,7 @@
             'new_from_deprecated' => {
                 type         => 'leaf',
                 value_type   => 'enum',
-                choice       => [qw/cds_file perl_file ini_file augeas custom/],
+                choice       => [qw/cds_file perl_file ini_file custom/],
                 migrate_from => {
                     formula   => '$replace{$old}',
                     variables => { old => '- deprecated_p' },
@@ -313,13 +312,13 @@
                 warn_unless_match =>
                   { foo => { msg => '', fix => '$_ = "foo".$_;' } },
             },
-            list_with_migrate_keys_from => {
+            list_with_migrate_values_from => {
                 type  => 'list',
                 cargo => {
                     type       => 'leaf',
                     value_type => 'string'
                 },
-                migrate_keys_from => '- lista',
+                migrate_values_from => '- lista',
             },
             hash_with_migrate_keys_from => {
                 type       => 'hash',
@@ -385,11 +384,6 @@
                   } qw/warn allow forbid suppress/
             ),
 
-            ## too difficult to correctly test Augeas here
-            'sshd_augeas' => {
-                type              => 'node',
-                config_class_name => 'MasterModel::SshdWithAugeas',
-            },
         ],
         description => [ tree_macro => 'controls behavior of other elements' ],
         author    => "dod\@foo.com",
