@@ -1,22 +1,20 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2013 by Dominique Dumont.
+# This software is Copyright (c) 2014 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Itself ;
-{
-  $Config::Model::Itself::VERSION = '1.239';
-}
-
+$Config::Model::Itself::VERSION = '1.242';
 use Mouse ;
-use namespace::autoclean;
+use Config::Model 2.055;
+use 5.010;
 
 use IO::File ;
-use Log::Log4perl;
+use Log::Log4perl 1.11;
 use Carp ;
 use Data::Dumper ;
 use File::Find ;
@@ -177,13 +175,26 @@ sub read_all {
         check => $force_load ? 'no' : 'yes'
     ) ;
 
-    # load annotations
+    # load annotations and comment header
     for my $file (@files) {
         $logger->info("loading annotations from file $file");
         my $fh = IO::File->new($file) || die "Can't open $file: $!" ;
         my @lines = $fh->getlines ;  
         $fh->close;
         $model_obj->load_pod_annotation(join('',@lines)) ;
+
+        my @headers ;
+        foreach my $l (@lines) {
+            if ($l =~ /^\s*#/ or $l =~ /^\s*$/){
+                push @headers, $l
+            }
+            else {
+                last;
+            }
+        }
+        my $rel_file = $file ;
+        $rel_file =~ s/^$dir\/?//;
+        $self->{header}{$rel_file} = \@headers;
     }
 
     return $self->{map} = \%class_file_map ;
@@ -210,18 +221,6 @@ sub get_perl_data_model{
     # - Do NOT translate legacy warp parameters
     # - Do not compact elements name
 
-    # - move experience, description and level status back in class info.
-    # my $all_elt_data = $model->{element} || [] ;
-    # for (my $i = 0 ; $i < @$all_elt_data; $i ++) {
-    # 	my $elt_name = $all_elt_data->[$i++] ;
-    # 	my $elt_data = $all_elt_data->[$i] ;
-    # 	foreach my $item (qw/description/) {
-    # 	    my $moved_data = delete $elt_data->{$item}  ;
-    # 	    next unless defined $moved_data ;
-    # 	    push @{$model->{$item}}, $elt_name, $moved_data ; 
-    # 	}
-    # } 
-
     # don't forget to add name
     $model->{name} = $class_name if keys %$model;
 
@@ -293,7 +292,7 @@ sub write_all {
 
         next unless @data ; # don't write empty model
 
-        write_model_file ("$dir/$file", \@notes, \@data);
+        write_model_file ("$dir/$file", $self->{header}{$file}, \@notes, \@data);
     }
     
     $self->model_object->instance->clear_changes ;
@@ -320,7 +319,7 @@ sub write_model_snippet {
         my @notes = $self->model_object->grab("class:$class")->dump_annotations_as_pod ;
         my $class_dir = $class.'.d';
         $class_dir =~ s!::!/!g;
-        write_model_file ("$snippet_dir/$class_dir/$model_file", \@notes, [ $data ]);
+        write_model_file ("$snippet_dir/$class_dir/$model_file", [], \@notes, [ $data ]);
     }
 
     $self->model_object->instance->clear_changes ;
@@ -381,9 +380,10 @@ sub read_model_snippet {
 # New subroutine "write_model_file" extracted - Mon Mar 12 13:38:29 2012.
 #
 sub write_model_file {
-    my $wr_file = shift;
-    my $notes   = shift;
-    my $data    = shift;
+    my $wr_file  = shift;
+    my $comments = shift ;
+    my $notes    = shift;
+    my $data     = shift;
 
     my $wr_dir = dirname($wr_file);
     unless ( -d $wr_dir ) {
@@ -404,6 +404,7 @@ sub write_model_file {
     # munge pod text embedded in values to avoid spurious pod formatting
     $dump =~ s/\n=/\n'.'=/g;
 
+    $wr->print(@$comments) ;
     $wr->print( $dump, ";\n\n" );
 
     $wr->print( join( "\n", @$notes ) );
@@ -464,41 +465,35 @@ sub get_dot_diagram {
 
     my $meta_class = $self->{model_object}->fetch_element('class') ;
     foreach my $class_name ($meta_class->fetch_all_indexes ) {
-        my $c_model = $self->{model_object}->config_model->get_raw_model($class_name);
-        my $elts = $c_model->{element} || []; # array ref
-
         my $d_class = $class_name ;
         $d_class =~ s/::/__/g;
 
         my $elt_list = '';
         my $use = '';
-        for (my $idx = 0; $idx < @$elts; $idx += 2) {
-            my $elt_info = $elts->[$idx] ;
-            my @elt_names = ref $elt_info ? @$elt_info : ($elt_info) ;
-            my $type = $elts->[$idx+1]{type} ;
 
-            foreach my $elt_name (@elt_names) {
-                my $of = '';
-                my $cargo = $elts->[$idx+1]{cargo}{type} ;
-                $of = " of $cargo" if defined $cargo ;
-                $elt_list .= "- $elt_name ($type$of)\\n";
-                $use .= $self->scan_used_class($d_class,$elt_name,
-                                               $elts->[$idx+1]);
+        my $class_obj =  $self->{model_object}->grab(qq!class:"$class_name"!);
+        my @elts =  $class_obj ->grab(qq!element!) ->fetch_all_indexes ;
+        foreach my $elt_name ( @elts ) {
+            my $of = '';
+            my $elt_obj = $class_obj->grab(qq!element:"$elt_name"!) ;
+            my $type = $elt_obj->grab_value("type") ;
+            if ($type =~ /^list|hash$/) {
+                my $cargo = $elt_obj->grab("cargo");
+                my $ct = $cargo->grab_value("type") ;
+                $of = " of $ct" ;
+                $use .= $self->scan_used_class($d_class,$elt_name,$cargo);
             }
+            else {
+                $use .= $self->scan_used_class($d_class,$elt_name,$elt_obj);
+            }
+            $elt_list .= "- $elt_name ($type$of)\\n";
         }
 
         $dot .= $d_class 
              .  qq! [shape=box label="$class_name\\n$elt_list"];\n!
              .  $use . "\n";
 
-        my $include = $c_model->{include} ;
-        if (defined $include) {
-            my $inc_ref = ref $include ? $include : [ $include ] ;
-            foreach my $t (@$inc_ref) {
-                $t =~ s/::/__/g;
-                $dot.= qq!$d_class -> $t ;\n!;
-            }
-        }
+        $dot .= $self->scan_includes($class_name, $class_obj) ;
     }
 
     $dot .="}\n";
@@ -506,43 +501,67 @@ sub get_dot_diagram {
     return $dot ;
 }
 
-sub scan_used_class {
-    my ($self,$d_class,$elt_name,$ref) = @_ ;
-    my $res = '' ;
+sub scan_includes {
+    my ($self,$class_name, $class_obj) = @_ ;
+    my $d_class = $class_name ;
+    $d_class =~ s/::/__/g;
 
-    if (ref($ref) eq 'HASH') {
-        foreach my $k (keys %$ref) {
-            my $v = $ref->{$k} ;
-            if ($k eq 'config_class_name') {
-                $v =~ s/::/__/g;
-                $res .= qq!$d_class -> $v !
-                      . qq![ style=dashed, label="$elt_name" ];\n!;
-            }
-            if (ref $v) {
-                $res .= $self->scan_used_class($d_class,$elt_name,$v);
-            }
-        }
+    my @includes = $class_obj->grab('include')->fetch_all_values ;
+    my $dot = '';
+    foreach my $c (@includes) {
+        say "$class_name includes $c";
+        my $t = $c;
+        $t =~ s/::/__/g;
+        $dot.= qq!$d_class -> $t ;\n!;
     }
-    elsif (ref($ref) eq 'ARRAY') {
-        map {$res .= $self->scan_used_class($d_class,$elt_name,$_);} @$ref ;
-    }
-    return $res ;
+    return $dot;
+}
+
+sub scan_used_class {
+    my ($self,$d_class,$elt_name, $elt_obj) = @_ ;
+
+    # define leaf call back
+    my $disp_leaf = sub {
+        my ($scanner, $data_ref, $node,$element_name,$index, $leaf_object) = @_ ;
+        return unless $element_name eq 'config_class_name';
+        my $v =  $leaf_object->fetch;
+        return unless $v;
+        $v =~ s/::/__/g;
+        $$data_ref .= qq!$d_class -> $v !
+            . qq![ style=dashed, label="$elt_name" ];\n!;
+    } ;
+
+    # simple scanner, (print all values)
+    my $scan = Config::Model::ObjTreeScanner-> new (
+        leaf_cb => $disp_leaf, # only mandatory parameter
+    ) ;
+
+    my $result = '' ;
+    $scan->scan_node(\$result, $elt_obj) ;
+    return $result ;
 }
 
 __PACKAGE__->meta->make_immutable;
 
 1;
 
+
+# ABSTRACT: Model editor for Config::Model
+
 __END__
 
-
-
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Config::Model::Itself - Model editor for Config::Model
 
+=head1 VERSION
+
+version 1.242
+
 =head1 SYNOPSIS
 
  my $meta_model = Config::Model -> new ( ) ;
@@ -571,7 +590,6 @@ Config::Model::Itself - Model editor for Config::Model
  # create Curses user interface
  my $dialog = Config::Model::CursesUI-> new
       (
-       experience => 'advanced',
        store => $wr_back,
       ) ;
 
@@ -664,21 +682,20 @@ dashed lines. The name of the element is attached to the dashed line.
 
 =back
 
-=head1 AUTHOR
-
-Dominique Dumont, (ddumont at cpan dot org)
-
-=head1 COPYRIGHT
-
-Copyright (C) 2007-2012 by Dominique Dumont
-
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the LGPL terms.
-
 =head1 SEE ALSO
 
 L<Config::Model>, L<Config::Model::Node>,
 
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2014 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
 =cut
