@@ -41,7 +41,7 @@
                         '$t eq "leaf"' => {
                             choice => [
                                 qw/boolean enum integer reference
-                                  number uniline string/
+                                  number uniline string file dir/
                             ],
                             level     => 'normal',
                             mandatory => 1,
@@ -54,12 +54,15 @@
                 type       => 'leaf',
                 level      => 'hidden',
                 value_type => 'uniline',
-                summary    => "Override Config::Model::Value:",
+                summary    => "Override implementation of element",
                 description =>
-                  "Perl class name of a child of Config::Model::Value",
+                "Perl class name used to override the implementation of the configuration element. "
+                ."This override Perl class must inherit a Config::Model clas that matches the element type, "
+                ."i.e. Config::Model::Value, Config::Model::HashId, Config::Model::ListId "
+                ."or Config::Model::Node. Use with care.",
                 'warp'     => {
-                    follow  => { 't'            => '- type' },
-                    'rules' => [ '$t eq "leaf"' => { level => 'normal', } ]
+                    follow  => { 't'              => '- type' },
+                    'rules' => [ '$t and $t !~ /warped/' => { level => 'normal', } ]
                 }
             },
 
